==> nas_1.9.orig.tar.gz: nas-1.9/server/dia/swapreq.c <==
/*
 * Copyright 1993 Network Computing Devices, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name Network Computing Devices, Inc. not be
 * used in advertising or publicity pertaining to distribution of this 
 * software without specific, written prior permission.
 * 
 * THIS SOFTWARE IS PROVIDED `AS-IS'.  NETWORK COMPUTING DEVICES, INC.,
 * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT
 * LIMITATION ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NONINFRINGEMENT.  IN NO EVENT SHALL NETWORK
 * COMPUTING DEVICES, INC., BE LIABLE FOR ANY DAMAGES WHATSOEVER, INCLUDING
 * SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOSS OF USE, DATA,
 * OR PROFITS, EVEN IF ADVISED OF THE POSSIBILITY THEREOF, AND REGARDLESS OF
 * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * $NCDId: @(#)swapreq.c,v 1.3 1994/04/07 20:56:35 greg Exp $
 */
/************************************************************
Some portions derived from: 

Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts,
and the Massachusetts Institute of Technology, Cambridge, Massachusetts.

                        All Rights Reserved

Permission to use, copy, modify, and distribute this software and its 
documentation for any purpose and without fee is hereby granted, 
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in 
supporting documentation, and that the names of Digital or MIT not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.  

DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.

********************************************************/

#include <audio/audio.h>
#include <audio/Aproto.h>
#include "misc.h"

/* Byte swap a list of longs */

void
SwapLongs(register long *list, register unsigned long count)
{
    register char n;

    while (count >= 8) {
        swapl(list + 0, n);
        swapl(list + 1, n);
        swapl(list + 2, n);
        swapl(list + 3, n);
        swapl(list + 4, n);
        swapl(list + 5, n);
        swapl(list + 6, n);
        swapl(list + 7, n);
        list += 8;
        count -= 8;
    }
    if (count != 0) {
        do {
            swapl(list, n);
            list++;
        } while (--count != 0);
    }
}

/* Byte swap a list of shorts */

void
SwapShorts(register short *list, register unsigned long count)
{
    register char n;

    while (count >= 16) {
        swaps(list + 0, n);
        swaps(list + 1, n);
        swaps(list + 2, n);
        swaps(list + 3, n);
        swaps(list + 4, n);
        swaps(list + 5, n);
        swaps(list + 6, n);
        swaps(list + 7, n);
        swaps(list + 8, n);
        swaps(list + 9, n);
        swaps(list + 10, n);
        swaps(list + 11, n);
        swaps(list + 12, n);
        swaps(list + 13, n);
        swaps(list + 14, n);
        swaps(list + 15, n);
        list += 16;
        count -= 16;
    }
    if (count != 0) {
        do {
            swaps(list, n);
            list++;
        } while (--count != 0);
    }
}

void
SwapConnClientPrefix(auConnClientPrefix * pCCP)
{
    register char n;

    swaps(&pCCP->majorVersion, n);
    swaps(&pCCP->minorVersion, n);
    swaps(&pCCP->nbytesAuthProto, n);
    swaps(&pCCP->nbytesAuthString, n);
}

==> nas_1.9.4.orig.tar.gz: nas-1.9.4/server/dia/swapreq.c <==
/*
 * Copyright 1993 Network Computing Devices, Inc.
 *
 * Permission to use, copy, modify, distribute, and sell this software and
 * its documentation for any purpose is hereby granted without fee, provided
 * that the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name Network Computing Devices, Inc. not be
 * used in advertising or publicity pertaining to distribution of this 
 * software without specific, written prior permission.
 * 
 * THIS SOFTWARE IS PROVIDED `AS-IS'.  NETWORK COMPUTING DEVICES, INC.,
 * DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING WITHOUT
 * LIMITATION ALL IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
 * PARTICULAR PURPOSE, OR NONINFRINGEMENT.  IN NO EVENT SHALL NETWORK
 * COMPUTING DEVICES, INC., BE LIABLE FOR ANY DAMAGES WHATSOEVER, INCLUDING
 * SPECIAL, INCIDENTAL OR CONSEQUENTIAL DAMAGES, INCLUDING LOSS OF USE, DATA,
 * OR PROFITS, EVEN IF ADVISED OF THE POSSIBILITY THEREOF, AND REGARDLESS OF
 * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 * 
 * $NCDId: @(#)swapreq.c,v 1.3 1994/04/07 20:56:35 greg Exp $
 */
/************************************************************
Some portions derived from: 

Copyright 1987 by Digital Equipment Corporation, Maynard, Massachusetts,
and the Massachusetts Institute of Technology, Cambridge, Massachusetts.

                        All Rights Reserved

Permission to use, copy, modify, and distribute this software and its 
documentation for any purpose and without fee is hereby granted, 
provided that the above copyright notice appear in all copies and that
both that copyright notice and this permission notice appear in 
supporting documentation, and that the names of Digital or MIT not be
used in advertising or publicity pertaining to distribution of the
software without specific, written prior permission.  

DIGITAL DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL
DIGITAL BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR
ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
SOFTWARE.

********************************************************/

#include <audio/audio.h>
#include <audio/Aproto.h>
#include "misc.h"

/* Byte swap a list of longs */

void
SwapLongs(long *list, unsigned long count)
{
    char n;

    while (count >= 8) {
        swapl(list + 0, n);
        swapl(list + 1, n);
        swapl(list + 2, n);
        swapl(list + 3, n);
        swapl(list + 4, n);
        swapl(list + 5, n);
        swapl(list + 6, n);
        swapl(list + 7, n);
        list += 8;
        count -= 8;
    }
    if (count != 0) {
        do {
            swapl(list, n);
            list++;
        } while (--count != 0);
    }
}

/* Byte swap a list of shorts */

void
SwapShorts(short *list, unsigned long count)
{
    char n;

    while (count >= 16) {
        swaps(list + 0, n);
        swaps(list + 1, n);
        swaps(list + 2, n);
        swaps(list + 3, n);
        swaps(list + 4, n);
        swaps(list + 5, n);
        swaps(list + 6, n);
        swaps(list + 7, n);
        swaps(list + 8, n);
        swaps(list + 9, n);
        swaps(list + 10, n);
        swaps(list + 11, n);
        swaps(list + 12, n);
        swaps(list + 13, n);
        swaps(list + 14, n);
        swaps(list + 15, n);
        list += 16;
        count -= 16;
    }
    if (count != 0) {
        do {
            swaps(list, n);
            list++;
        } while (--count != 0);
    }
}

void
SwapConnClientPrefix(auConnClientPrefix * pCCP)
{
    char n;

    swaps(&pCCP->majorVersion, n);
    swaps(&pCCP->minorVersion, n);
    swaps(&pCCP->nbytesAuthProto, n);
    swaps(&pCCP->nbytesAuthString, n);
}
